@@ -132,7 +132,8 @@ class Data(withIdentification, withPrinting, withTiming):
             self.step_func_m = self.step_func_m()
         return self.step_func_m
 
-    @cached_property
+    ###@cached_property
+    @property
     def changed_asdict(self):
         """Evaluate and return all fields in 'changed'."""
         return {lazy_field: self.field_funcs_m[lazy_field] for lazy_field in self.changed}
@@ -231,7 +232,8 @@ class Data(withIdentification, withPrinting, withTiming):
         newfields.update(updated_fields)
         return Data(uuid, uuids, self.history << step, **newfields)
 
-    @cached_property
+    ###@cached_property
+    @property
     def eager(self):
         """Touch every lazy field by accessing all fields.
 
@@ -240,7 +242,8 @@ class Data(withIdentification, withPrinting, withTiming):
             _ = self[f]
         return self
 
-    @cached_property
+    ###@cached_property
+    @property
     def Xy(self):
         return self["X"], self["y"]
 
@@ -272,7 +275,7 @@ class Data(withIdentification, withPrinting, withTiming):
 
     # REMINDER Data is mutable in rare occasions: setitem/delitem/
 
-    @lru_cache
+    ###@lru_cache
     def arff(self, relation, description):
         Xt = [untranslate_type(typ) for typ in self.Xt]
         Yt = [untranslate_type(typ) for typ in self.Yt]
@@ -332,7 +335,7 @@ class Data(withIdentification, withPrinting, withTiming):
         #     if callable(attr) and hasattr(attr, "cacheclear"):
         #         attr.cacheclear()
 
-    @lru_cache()
+    ###@lru_cache()
     def __getitem__(self, key):
         """Safe access to a field, with a friendly error message.
 
@@ -382,27 +385,6 @@ class Data(withIdentification, withPrinting, withTiming):
         if item.startswith("__"):
             return super().__getattribute__(item)
 
-        # Handle pandas suffix.
-        if item.endswith("_pd"):
-            name = item[:-3]
-            if name.upper() not in self.field_funcs_m:
-                print(f"Field {name} not found when trying to convert it to pandas. Available ones:",
-                      self.field_funcs_m)
-                exit()
-            name = name.upper()
-            from pandas import DataFrame
-            desc = name[:-2] + "d_m" if name.endswith("_m") else name + "d"
-            if desc in self.field_funcs_m:
-                return DataFrame(self[name], columns=self[desc])
-            else:
-                return DataFrame(self.field_funcs_m[name])
-
-        # Handle numpy shortcuts
-        if item.endswith("w"):
-            return self[item[:-1]].shape[0]
-        if item.endswith("h"):
-            return self[item[:-1]].shape[1]
-
         # Handle field access
         if item in self.field_funcs_m or item.upper() in self.field_funcs_m:
             return self[item]
@@ -423,36 +405,6 @@ class Data(withIdentification, withPrinting, withTiming):
         from aiuna.step.let import Let
         self.mutate(self >> Let(field=key, value=value))
 
-    # importante TODO
-    # *                         product
-    # **                        cached product
-    # ~                         sample
-    # ~~                        ?
-    # s0 | s1 | s2              seq
-    # s0 | ...                  seq s0,s0,...,s0
-    # +s                        seq s0,s1,...,sn
-    #
-
-    # @ cache
-    # & | ^ // %
-    # -step -> hold
-    # ~step -> sample
-    #  ...
-    # +step -> permite ser destrutivo?
-
-    # d.hash * A.hash * B.hash / e.hash
-    # s.id
-    # update() deveria aceitar qq obj com: {hash, id ?} ou aceitar hexmd5?
-
-    # ###########################################
-    # aceitar repetições de step, melhorar hash ou forçar sanduiches de step recheados com algo inerte?
-    # coisas a considerar no hash:
-    #       embaralhamento?
-    #       AB != BA
-    #       AAAAA sem colisão
-    #       AA != I
-    # ###########################################
-
     def items(self):
         # TODO quais ficam de fora de fields? são importantes pra iterar?
         for k in self:
@@ -478,26 +430,28 @@ class Data(withIdentification, withPrinting, withTiming):
         return new(X=X, y=y, Xd=Xd, Yd=Yd, Xt=Xt, Yt=Yt)
 
     # @property
-    # @lru_cache()
+    # ###@lru_cache()
     # def ids_lst(self):  #TODO ainda precisa?
     #     return [self.uuids[name].id for name in self.names]
     #
     # @property
-    # @lru_cache()
+    # ###@lru_cache()
     # def ids_str(self):  #TODO ainda precisa?
     #     return ','.join(self.ids_lst)
     #
     # @property
-    # @lru_cache()
+    # ###@lru_cache()
     # def names_str(self):  #TODO ainda precisa?
     #     return ','.join(self.names)
 
-    # @cached_property
+    # ###@cached_property
+    @property
     # def picklable(self):
     #     """Remove unpicklable parts."""
     #     return self.picklable_()[0]
     #
-    # @cached_property
+    # ###@cached_property
+    @property
     # def unpicklable(self):
     #     """Restore unpicklable parts."""
     #     return self.unpicklable_([{}])
@@ -543,8 +497,8 @@ class Data(withIdentification, withPrinting, withTiming):
         """Information to create an icon for this Data object."""
         return {"id": self.id, "step": self.step.asdict_rec, "colors": colors(self.id)}
 
+    # ###@cached_property
     @property
-    # @cached_property
     def past(self):
         """Map ancestor_id -> afterstep/icon_colors. Last item refers to the current Data object."""
         from aiuna.content.root import Root
@@ -561,5 +515,61 @@ def untranslate_type(name):
         return name
     if name in ["real", "int"]:
         return "NUMERIC"
-    else:
-        raise Exception("Unknown type:", name)
+    raise Exception("Unknown type:", name)
+
+
+""" importante TODO
+
+-({a0, a1} + {b0, b1}) = a0 | a1 | + {b0, b1} 
+
+
+    step =    an infinitely nested unit set (INUS)    A = {{ ... {a} ... }}; or,
+              a set of steps                          D = {A, B, C}
+
+    A * B                     product            (** cached product)
+    A + B                     union
+    A | B                     stack
+    +S                        summation (union) of all unit sets in stack S
+    -A                        stacking (disunion) of all unit sets in set A
+
+    Properties (A: set, S: stack, a: INUS)
+    +A = error
+    -S = error
+    -a = a
+
+    -(A | B) = +A | +B
+    s0 | s1 | s2              sequence s0,s1,s2
+    s0 | ...                  sequence s0,s0,...,s0
+    +S                        sequence s0,s1,...,sn
+    +(A|B) = {a0,a1,b0,b1}
+    -{a0,a1,b0,b1} = (A|B)
+
+    ~                         sample
+    ~~                        ?
+
+    @ cache
+    & | ^ // %
+    -step -> hold
+    ~step -> sample
+     ...
+    +step -> permite ser destrutivo?
+
+    d.hash * A.hash * B.hash / e.hash
+    s.id
+    update() deveria aceitar qq obj com: {hash, id ?} ou aceitar hexmd5?
+
+    ###########################################
+    aceitar repetições de step, melhorar hash ou forçar sanduiches de step recheados com algo inerte?
+    coisas a considerar no hash:
+          embaralhamento?
+          AB != BA
+          AAAAA sem colisão
+          AA != I
+    ###########################################
+
+    ------------------------
+    def alternativa, que enfraquece o uso dos ops unários:
+    A unit set is equivalent to its contained element.
+    A stack of a single element is the element itself.
+    ------------------------
+"""
